@@ -49,7 +49,7 @@
 #' The response is generated as by drawing one observation of n different 
 #' Bernoulli random variables of parameters logit^\{-1\}(XB).
 #' 
-#' The details of the procedure are developped by Durif et al. (2017).
+#' The details of the procedure are developped by Durif et al. (2018).
 #' 
 #' @param n the number of observations in the sample.
 #' @param p the number of covariates in the sample.
@@ -103,13 +103,14 @@
 #' (with the command \code{set.seed}) used for random number generation.}
 #' 
 #' @references 
-#' Durif G., Modolo L., Michaelsson J., Mold J. E., Lambert-Lacroix S., 
-#' Picard F. (2017). High Dimensional Classification with combined Adaptive 
-#' Sparse PLS and Logistic Regression, (in prep), 
-#' available on (\url{http://arxiv.org/abs/1502.05933}).
+#' Durif, G., Modolo, L., Michaelsson, J., Mold, J.E., Lambert-Lacroix, S., 
+#' Picard, F., 2018. High dimensional classification with combined 
+#' adaptive sparse PLS and logistic regression. Bioinformatics 34, 
+#' 485--493. \doi{10.1093/bioinformatics/btx571}.
+#' Available at \url{http://arxiv.org/abs/1502.05933}.
 #' 
 #' @author
-#' Ghislain Durif (\url{http://thoth.inrialpes.fr/people/gdurif/}).
+#' Ghislain Durif (\url{https://gdurif.perso.math.cnrs.fr/}).
 #' 
 #' @seealso \code{\link{sample.cont}}
 #' 
@@ -127,7 +128,8 @@
 #' str(sample1)
 #' 
 #' @export
-sample.bin = function(n, p, kstar, lstar, beta.min, beta.max, mean.H=0, sigma.H, sigma.F, seed=NULL) {
+sample.bin = function(n, p, kstar, lstar, beta.min, beta.max, 
+                      mean.H=0, sigma.H=1, sigma.F=1, seed=NULL) {
 	
 	### input
 	# n : sample size
@@ -147,11 +149,11 @@ sample.bin = function(n, p, kstar, lstar, beta.min, beta.max, mean.H=0, sigma.H,
 	}
 	
 	if((!is.numeric(mean.H)) || (!is.numeric(sigma.H)) || (!is.numeric(sigma.F)) ) {
-		stop("Message from sample.cont: mean.H, sigma.H, sigma.F, sigma.E are not of valid type")
+		stop("Message from sample.cont: mean.H, sigma.H, sigma.F are not of valid type")
 	}
 	
 	if((sigma.H<0) || (sigma.F<0)) {
-		stop("Message from sample.cont: sigma.H, sigma.F, sigma.E are not of valid type")
+		stop("Message from sample.cont: sigma.H, sigma.F are not of valid type")
 	}
 	
 	if(n<1) {
